# Licensing

napari is distributed under the BSD-3-Clause license, a copy of which is available
[here](https://github.com/napari/napari/blob/latest/LICENSE).

```{include} ../../LICENSE
:literal: true
```

```{include} ../../EULA.md
```
